#Processing data----
##loading libraries----
library(vegan)
library(FD)
library(picante)
library(dplyr)
library(lme4)
##loading and processing data----
otu_table<-read.table("otu_table.txt",header=T) #Table S1
tomato_traits<-read.table("tomato_traits.txt",header=T) #Table A1
phylogeny<- read.table("tomato_dis.txt", header=T) #Table S2

#Transform otu table
otu_table_hell<-decostand(otu_table,method="hellinger")

#log transform numerical data
tomato_traits[,c(4:42)] <- log(tomato_traits[,c(4:42)]+0.001)

#pcoa on phylogeny tomatoes
phylo <- phylogeny^2
pcoa_phylo<-capscale(phylo ~1)
plot(pcoa_phylo)
#check the variance explained by each axis
summary(pcoa_phylo)
pcoa.phylo_r1 <- summary(pcoa_phylo)$sites[,1:4]

####-----
#Clustering and correlations----
##k-means clustering----
set.seed(20)
km.3group <- kmeans(tomato_traits[,c(4:41)], 3, nstart = 25)

##Correlations----
S<-specnumber(otu_table_hell)
simpson<-diversity(otu_table_hell, index = "simpson")
shannon<-diversity(otu_table_hell, index = "shannon")

table_for_correlations<-cbind(S,simpson,shannon,tomato_traits[,c(4:42)])

#To do the correlations, first test for normality
#Build a lm model with simpson or shannon

modelsim <- lm(simpson ~ Tomato_Number + Spod_survival + CN_ratio + As, 
               data= tomato_traits)
anova(modelsim) #Spod survival significant 

modelshan <- lm(shannon ~ Tomato_Number + Spod_survival + CN_ratio + As, 
                data= tomato_traits)
anova(modelshan) #Spod survival significant

#Plotting residuals
so.res<-simulateResiduals(fittedModel=modelsim)
testUniformity(simulationOutput=so.res)

so.res<-simulateResiduals(fittedModel=modelshan)
testUniformity(simulationOutput=so.res)

#Now for the correlation test. 
Correlation_test <- cor(table_for_correlations, method = c("pearson")) 
write.table(Correlation_test, file = "cor_test2.csv", sep = ",", col.names = NA,
            qmethod = "double")
####-----
#Main results----
##Run the PCA analysis----
mod1<- rda(tomato_traits[,c(4:41)]~1)
plot(mod1)
summary(mod1)

##OTU COMMUNITY COMPOSITION ANALYSIS----
#Select variables that don't covary for each trait group (fruit, resistance or soil) apart
rda.mod<-rda(otu_table_hell ~., data=tomato_traits[,c(4:9)]) 

anova(rda.mod)

rda.0<- rda(otu_table_hell ~ 1, data=tomato_traits[,c(4:9)])
step.envf <- ordistep(rda.0, scope=formula(rda.mod)) 

anova(step.envf )
summary(step.envf)
#Select Tomato_Number (6), Spod_survival (13), CN_ratio, As (20,22)

##All  varieties----
#separate in resistance traits, phylogeny of tomato, morphological traits, soil variables
otu_varpart <- varpart(otu_table_hell, tomato_traits[,c(13)], pcoa.phylo_r1, tomato_traits[,6], tomato_traits[,c(20,22)])

##No wild varieties----
#Remove wild species (pimpenellifolium and habrochaites)
Wild<-which(tomato_traits$Tomato_type2 == 1)
tomato_traits<-tomato_traits[-Wild,]
phylo<-phylo[-Wild,-Wild]
otu_table_hell<-otu_table_hell[-Wild,]
pcoa_phylo<-capscale(phylo ~1)
summary(pcoa_phylo)
pcoa.phylo_r1 <- summary(pcoa_phylo)$sites[,1]

#Select variables
rda.mod<-rda(otu_table_hell ~., data=tomato_traits[,c(18:42)]) 
rda.0<- rda(otu_table_hell ~ 1, data=tomato_traits[,c(18:42)])
step.envf <- ordistep(rda.0, scope=formula(rda.mod))
anova(step.envf)
#Selects: Spod_survival (13), Carbon, Mg, CN_ratio (19,20,31) 

#Run varpart(no wild varieties)
otu_varpart <- varpart(otu_table_hell, tomato_traits[,13], pcoa.phylo_r1, tomato_traits[,c(19,20,31)])
plot(otu_varpart, bg=1:3, Xnames=c('resistance','phylogeny','soil'), id.size=0.75)
otu_varpart
